// Sample inventory data
const inventoryData = [
  {
    name: "Green Tea",
    image: "images/green-tea.jpg",
    quantity: 120,
    dailyUsage: 15,
    expiryDays: null
  },
  {
    name: "Black Tea",
    image: "images/black-tea.jpg",
    quantity: 80,
    dailyUsage: 10,
    expiryDays: null
  },
  {
    name: "Herbal Tea",
    image: "images/herbal-tea.jpg",
    quantity: 50,
    dailyUsage: 8,
    expiryDays: null
  }
];

function calculateExpiryDays(item) {
  return Math.floor(item.quantity / item.dailyUsage);
}

function createInventoryItem(item) {
  const expiryDays = calculateExpiryDays(item);
  
  const itemElement = document.createElement('div');
  itemElement.className = 'inventory-item';
  
  itemElement.innerHTML = `
    <div class="item-image">
      <img src="${item.image}" alt="${item.name}">
    </div>
    <div class="item-details">
      <div class="item-name">${item.name}</div>
      <div class="item-quantity">
        <span>Quantity:</span>
        <input type="number" value="${item.quantity}" min="0">
      </div>
      <div class="daily-usage">
        <span>Daily Usage:</span>
        <input type="number" value="${item.dailyUsage}" min="0">
      </div>
      <div class="expiry-days">
        <span>Expiry Days:</span>
        ${Array.from({length: expiryDays}, (_, i) => `
          <span class="leaf-icon" style="opacity: ${1 - (i / expiryDays)}"></span>
        `).join('')}
      </div>
    </div>
  `;
  
  return itemElement;
}

function renderInventory() {
  const inventoryGrid = document.querySelector('.inventory-grid');
  inventoryGrid.innerHTML = '';
  
  inventoryData.forEach(item => {
    const itemElement = createInventoryItem(item);
    inventoryGrid.appendChild(itemElement);
  });
}

document.addEventListener('DOMContentLoaded', () => {
  renderInventory();
});